icu4x
library
Classes
Bidi
An ICU4X Bidi object, containing loaded bidi data
BidiInfo
An object containing bidi information for a given string, produced by for_text() on Bidi
BidiMirroringGlyph
See the Rust documentation for BidiMirroringGlyph for more information.
BidiParagraph
Bidi information for a single processed paragraph
Calendar
See the Rust documentation for AnyCalendar for more information.
CanonicalCombiningClassMap
Lookup of the Canonical_Combining_Class Unicode property
CanonicalComposition
The raw canonical composition operation.
CanonicalDecomposition
The raw (non-recursive) canonical decomposition operation.
CaseMapCloser
See the Rust documentation for CaseMapCloser for more information.
CaseMapper
See the Rust documentation for CaseMapper for more information.
CodePointMapData16
An ICU4X Unicode Map Property object, capable of querying whether a code point (key) to obtain the Unicode property value, for a specific Unicode property.
CodePointMapData8
An ICU4X Unicode Map Property object, capable of querying whether a code point (key) to obtain the Unicode property value, for a specific Unicode property.
CodePointRangeIterator
An iterator over code point ranges, produced by CodePointSetData or
one of the CodePointMapData types
CodePointRangeIteratorResult
Result of a single iteration of CodePointRangeIterator .
Logically can be considered to be an Option<RangeInclusive<DiplomatChar>>,
CodePointSetBuilder
See the Rust documentation for CodePointInversionListBuilder for more information.
CodePointSetData
An ICU4X Unicode Set Property object, capable of querying whether a code point is contained in a set based on a Unicode property.
Collator
See the Rust documentation for Collator for more information.
CollatorOptions
See the Rust documentation for CollatorOptions for more information.
CollatorResolvedOptions
See the Rust documentation for ResolvedCollatorOptions for more information.
ComposingNormalizer
See the Rust documentation for ComposingNormalizer for more information.
DataProvider
An ICU4X data provider, capable of loading ICU4X data keys from some source.
Date
An ICU4X Date object capable of containing a date for any calendar.
DateFields
🚧 This API is experimental and may experience breaking changes outside major releases.
DateFormatter
See the Rust documentation for DateTimeFormatter for more information.
DateFormatterGregorian
See the Rust documentation for FixedCalendarDateTimeFormatter for more information.
DateFromFieldsOptions
🚧 This API is experimental and may experience breaking changes outside major releases.
DateTime
An ICU4X DateTime object capable of containing a date and time for any calendar.
DateTimeFormatter
See the Rust documentation for DateTimeFormatter for more information.
DateTimeFormatterGregorian
See the Rust documentation for FixedCalendarDateTimeFormatter for more information.
DateTimeMismatchedCalendarError
See the Rust documentation for MismatchedCalendarError for more information.
Decimal
See the Rust documentation for Decimal for more information.
DecimalFormatter
An ICU4X Decimal Format object, capable of formatting a Decimal as a string.
DecimalLimitError
Additional information: 1
Decomposed
The outcome of non-recursive canonical decomposition of a character.
second will be NUL when the decomposition expands to a single character
(which may or may not be the original one)
DecomposingNormalizer
See the Rust documentation for DecomposingNormalizer for more information.
DisplayNamesOptions
🚧 This API is experimental and may experience breaking changes outside major releases.
EmojiSetData
An ICU4X Unicode Set Property object, capable of querying whether a code point is contained in a set based on a Unicode property.
ExemplarCharacters
A set of "exemplar characters" for a given locale.
GeneralCategoryGroup
A mask that is capable of representing groups of General_Category values.
GeneralCategoryNameToGroupMapper
A type capable of looking up General Category Group values from a string name.
GraphemeClusterBreakIteratorLatin1
See the Rust documentation for GraphemeClusterBreakIterator for more information.
GraphemeClusterBreakIteratorUtf16
See the Rust documentation for GraphemeClusterBreakIterator for more information.
GraphemeClusterBreakIteratorUtf8
See the Rust documentation for GraphemeClusterBreakIterator for more information.
GraphemeClusterSegmenter
An ICU4X grapheme-cluster-break segmenter, capable of finding grapheme cluster breakpoints
in strings.
IanaParser
A mapper between IANA time zone identifiers and BCP-47 time zone identifiers.
IanaParserExtended
A mapper between IANA time zone identifiers and BCP-47 time zone identifiers.
IsoDate
An ICU4X Date object capable of containing a ISO-8601 date
IsoDateTime
An ICU4X DateTime object capable of containing a ISO-8601 date and time.
IsoWeekOfYear
See the Rust documentation for IsoWeekOfYear for more information.
LineBreakIteratorLatin1
See the Rust documentation for LineBreakIterator for more information.
LineBreakIteratorUtf16
See the Rust documentation for LineBreakIterator for more information.
LineBreakIteratorUtf8
See the Rust documentation for LineBreakIterator for more information.
LineBreakOptions
See the Rust documentation for LineBreakOptions for more information.
LineSegmenter
An ICU4X line-break segmenter, capable of finding breakpoints in strings.
ListFormatter
See the Rust documentation for ListFormatter for more information.
Locale
An ICU4X Locale, capable of representing strings like "en-US".
LocaleCanonicalizer
A locale canonicalizer.
LocaleDirectionality
See the Rust documentation for LocaleDirectionality for more information.
LocaleDisplayNamesFormatter
🚧 This API is experimental and may experience breaking changes outside major releases.
LocaleExpander
A locale expander.
LocaleFallbackConfig
Collection of configurations for the ICU4X fallback algorithm.
LocaleFallbacker
An object that runs the ICU4X locale fallback algorithm.
LocaleFallbackerWithConfig
An object that runs the ICU4X locale fallback algorithm with specific configurations.
LocaleFallbackIterator
An iterator over the locale under fallback.
Logger
An object allowing control over the logging used
PluralCategories
See the Rust documentation for categories for more information.
PluralOperands
See the Rust documentation for PluralOperands for more information.
PluralRules
See the Rust documentation for PluralRules for more information.
PropertyValueNameToEnumMapper
A type capable of looking up a property value from a string name.
RegionDisplayNames
🚧 This API is experimental and may experience breaking changes outside major releases.
ReorderedIndexMap
Thin wrapper around a vector that maps visual indices to source indices
ScriptExtensionsSet
An object that represents the Script_Extensions property for a single character
ScriptWithExtensions
An ICU4X ScriptWithExtensions map object, capable of holding a map of codepoints to scriptextensions values
ScriptWithExtensionsBorrowed
A slightly faster ScriptWithExtensions object
SentenceBreakIteratorLatin1
See the Rust documentation for SentenceBreakIterator for more information.
SentenceBreakIteratorUtf16
See the Rust documentation for SentenceBreakIterator for more information.
SentenceBreakIteratorUtf8
See the Rust documentation for SentenceBreakIterator for more information.
SentenceSegmenter
An ICU4X sentence-break segmenter, capable of finding sentence breakpoints in strings.
Time
An ICU4X Time object representing a time in terms of hour, minute, second, nanosecond
TimeFormatter
See the Rust documentation for NoCalendarFormatter for more information.
TimeZone
See the Rust documentation for TimeZone for more information.
TimeZoneAndCanonical
See the Rust documentation for TimeZoneAndCanonical for more information.
TimeZoneAndCanonicalAndNormalized
See the Rust documentation for TimeZoneAndCanonicalAndNormalized for more information.
TimeZoneAndCanonicalAndNormalizedIterator
See the Rust documentation for TimeZoneAndCanonicalAndNormalizedIter for more information.
TimeZoneAndCanonicalIterator
See the Rust documentation for TimeZoneAndCanonicalIter for more information.
TimeZoneFormatter
See the Rust documentation for NoCalendarFormatter for more information.
TimeZoneInfo
See the Rust documentation for TimeZoneInfo for more information.
TimeZoneInvalidOffsetError
Additional information: 1
TimeZoneIterator
See the Rust documentation for TimeZoneIter for more information.
TitlecaseMapper
See the Rust documentation for TitlecaseMapper for more information.
TitlecaseOptions
See the Rust documentation for TitlecaseOptions for more information.
UtcOffset
See the Rust documentation for UtcOffset for more information.
VariantOffsets
See the Rust documentation for VariantOffsets for more information.
VariantOffsetsCalculator
See the Rust documentation for VariantOffsetsCalculator for more information.
WeekdaySetIterator
Documents which days of the week are considered to be a part of the weekend
WeekInformation
A Week calculator, useful to be passed in to week_of_year() on Date and DateTime types
WindowsParser
A mapper between Windows time zone identifiers and BCP-47 time zone identifiers.
WordBreakIteratorLatin1
See the Rust documentation for WordBreakIterator for more information.
WordBreakIteratorUtf16
See the Rust documentation for WordBreakIterator for more information.
WordBreakIteratorUtf8
See the Rust documentation for WordBreakIterator for more information.
WordSegmenter
An ICU4X word-break segmenter, capable of finding word breakpoints in strings.
ZonedDateFormatter
See the Rust documentation for DateTimeFormatter for more information.
ZonedDateFormatterGregorian
See the Rust documentation for FixedCalendarDateTimeFormatter for more information.
ZonedDateTime
An ICU4X DateTime object capable of containing a date, time, and zone for any calendar.
ZonedDateTimeFormatter
See the Rust documentation for DateTimeFormatter for more information.
ZonedDateTimeFormatterGregorian
See the Rust documentation for FixedCalendarDateTimeFormatter for more information.
ZonedIsoDateTime
An ICU4X ZonedDateTime object capable of containing a ISO-8601 date, time, and zone.
ZonedTimeFormatter
See the Rust documentation for NoCalendarFormatter for more information.
Typedefs
Rune
= int
A Rune is a Unicode code point, such as a, or 💡.