BidiClass enum
See the Rust documentation for BidiClass for more information.
Values
- leftToRight → const BidiClass
-
See the Rust documentation for
LeftToRightfor more information. - rightToLeft → const BidiClass
-
See the Rust documentation for
RightToLeftfor more information. - europeanNumber → const BidiClass
-
See the Rust documentation for
EuropeanNumberfor more information. - europeanSeparator → const BidiClass
-
See the Rust documentation for
EuropeanSeparatorfor more information. - europeanTerminator → const BidiClass
-
See the Rust documentation for
EuropeanTerminatorfor more information. - arabicNumber → const BidiClass
-
See the Rust documentation for
ArabicNumberfor more information. - commonSeparator → const BidiClass
-
See the Rust documentation for
CommonSeparatorfor more information. - paragraphSeparator → const BidiClass
-
See the Rust documentation for
ParagraphSeparatorfor more information. - segmentSeparator → const BidiClass
-
See the Rust documentation for
SegmentSeparatorfor more information. - whiteSpace → const BidiClass
-
See the Rust documentation for
WhiteSpacefor more information. - otherNeutral → const BidiClass
-
See the Rust documentation for
OtherNeutralfor more information. - leftToRightEmbedding → const BidiClass
-
See the Rust documentation for
LeftToRightEmbeddingfor more information. - leftToRightOverride → const BidiClass
-
See the Rust documentation for
LeftToRightOverridefor more information. - arabicLetter → const BidiClass
-
See the Rust documentation for
ArabicLetterfor more information. - rightToLeftEmbedding → const BidiClass
-
See the Rust documentation for
RightToLeftEmbeddingfor more information. - rightToLeftOverride → const BidiClass
-
See the Rust documentation for
RightToLeftOverridefor more information. - popDirectionalFormat → const BidiClass
-
See the Rust documentation for
PopDirectionalFormatfor more information. - nonspacingMark → const BidiClass
-
See the Rust documentation for
NonspacingMarkfor more information. - boundaryNeutral → const BidiClass
-
See the Rust documentation for
BoundaryNeutralfor more information. - firstStrongIsolate → const BidiClass
-
See the Rust documentation for
FirstStrongIsolatefor more information. - leftToRightIsolate → const BidiClass
-
See the Rust documentation for
LeftToRightIsolatefor more information. - rightToLeftIsolate → const BidiClass
-
See the Rust documentation for
RightToLeftIsolatefor more information. - popDirectionalIsolate → const BidiClass
-
See the Rust documentation for
PopDirectionalIsolatefor more information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
longName(
) → String? - Get the "long" name of this property value (returns empty if property value is unknown)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortName(
) → String? - Get the "short" name of this property value (returns empty if property value is unknown)
-
toIntegerValue(
) → int - Convert to an integer value usable with ICU4C and CodePointMapData
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forChar(
Rune ch) → BidiClass -
See the Rust documentation for
for_charfor more information. -
fromIntegerValue(
int other) → BidiClass? - Convert from an integer value from ICU4C or CodePointMapData