levelAt method
Get the BIDI level at a particular byte index in the full text.
This integer is conceptually a unicode_bidi::Level,
and can be further inspected using the static methods on Bidi.
Returns 0 (equivalent to Level::ltr()) on error
Implementation
int levelAt(int pos) {
final result = _icu4x_BidiInfo_level_at_mv1(_ffi, pos);
return result;
}