CanonicalCombiningClass enum
See the Rust documentation for CanonicalCombiningClass for more information.
Values
- notReordered → const CanonicalCombiningClass
-
See the Rust documentation for
NotReorderedfor more information. - overlay → const CanonicalCombiningClass
-
See the Rust documentation for
Overlayfor more information. - hanReading → const CanonicalCombiningClass
-
See the Rust documentation for
HanReadingfor more information. - nukta → const CanonicalCombiningClass
-
See the Rust documentation for
Nuktafor more information. - kanaVoicing → const CanonicalCombiningClass
-
See the Rust documentation for
KanaVoicingfor more information. - virama → const CanonicalCombiningClass
-
See the Rust documentation for
Viramafor more information. - ccc10 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC10for more information. - ccc11 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC11for more information. - ccc12 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC12for more information. - ccc13 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC13for more information. - ccc14 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC14for more information. - ccc15 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC15for more information. - ccc16 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC16for more information. - ccc17 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC17for more information. - ccc18 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC18for more information. - ccc19 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC19for more information. - ccc20 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC20for more information. - ccc21 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC21for more information. - ccc22 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC22for more information. - ccc23 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC23for more information. - ccc24 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC24for more information. - ccc25 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC25for more information. - ccc26 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC26for more information. - ccc27 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC27for more information. - ccc28 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC28for more information. - ccc29 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC29for more information. - ccc30 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC30for more information. - ccc31 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC31for more information. - ccc32 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC32for more information. - ccc33 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC33for more information. - ccc34 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC34for more information. - ccc35 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC35for more information. - ccc36 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC36for more information. - ccc84 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC84for more information. - ccc91 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC91for more information. - ccc103 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC103for more information. - ccc107 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC107for more information. - ccc118 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC118for more information. - ccc122 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC122for more information. - ccc129 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC129for more information. - ccc130 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC130for more information. - ccc132 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC132for more information. - ccc133 → const CanonicalCombiningClass
-
See the Rust documentation for
CCC133for more information. - attachedBelowLeft → const CanonicalCombiningClass
-
See the Rust documentation for
AttachedBelowLeftfor more information. - attachedBelow → const CanonicalCombiningClass
-
See the Rust documentation for
AttachedBelowfor more information. - attachedAbove → const CanonicalCombiningClass
-
See the Rust documentation for
AttachedAbovefor more information. - attachedAboveRight → const CanonicalCombiningClass
-
See the Rust documentation for
AttachedAboveRightfor more information. - belowLeft → const CanonicalCombiningClass
-
See the Rust documentation for
BelowLeftfor more information. - below → const CanonicalCombiningClass
-
See the Rust documentation for
Belowfor more information. - belowRight → const CanonicalCombiningClass
-
See the Rust documentation for
BelowRightfor more information. - left → const CanonicalCombiningClass
-
See the Rust documentation for
Leftfor more information. - right → const CanonicalCombiningClass
-
See the Rust documentation for
Rightfor more information. - aboveLeft → const CanonicalCombiningClass
-
See the Rust documentation for
AboveLeftfor more information. - above → const CanonicalCombiningClass
-
See the Rust documentation for
Abovefor more information. - aboveRight → const CanonicalCombiningClass
-
See the Rust documentation for
AboveRightfor more information. - doubleBelow → const CanonicalCombiningClass
-
See the Rust documentation for
DoubleBelowfor more information. - doubleAbove → const CanonicalCombiningClass
-
See the Rust documentation for
DoubleAbovefor more information. - iotaSubscript → const CanonicalCombiningClass
-
See the Rust documentation for
IotaSubscriptfor more information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toIntegerValue(
) → int - Convert to an integer value usable with ICU4C and CodePointMapData
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forChar(
Rune ch) → CanonicalCombiningClass -
See the Rust documentation for
for_charfor more information. -
fromIntegerValue(
int other) → CanonicalCombiningClass? - Convert from an integer value from ICU4C or CodePointMapData
Constants
-
values
→ const List<
CanonicalCombiningClass> - A constant List of the values in this enum, in order of their declaration.