CodePointRangeIteratorResult class final
Result of a single iteration of CodePointRangeIterator.
Logically can be considered to be an Option<RangeInclusive<DiplomatChar>>,
start and end represent an inclusive range of code points [start, end],
and done will be true if the iterator has already finished. The last contentful
iteration will NOT produce a range done=true, in other words start and end are useful
values if and only if done=false.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override