CodePointSetData class final
An ICU4X Unicode Set Property object, capable of querying whether a code point is contained in a set based on a Unicode property.
See the Rust documentation for properties for more information.
See the Rust documentation for CodePointSetData for more information.
See the Rust documentation for CodePointSetDataBorrowed for more information.
- Implemented types
Constructors
- CodePointSetData.alnum()
-
Create a set for the
Alnumproperty, using compiled data.factory - CodePointSetData.alnumWithProvider(DataProvider provider)
-
Create a set for the
Alnumproperty, using a particular data source.factory - CodePointSetData.alphabetic()
-
Create a set for the
Alphabeticproperty, using compiled data.factory - CodePointSetData.alphabeticWithProvider(DataProvider provider)
-
Create a set for the
Alphabeticproperty, using a particular data source.factory - CodePointSetData.asciiHexDigit()
-
Create a set for the
Ascii_Hex_Digitproperty, using compiled data.factory - CodePointSetData.asciiHexDigitWithProvider(DataProvider provider)
-
Create a set for the
Ascii_Hex_Digitproperty, using a particular data source.factory - CodePointSetData.bidiControl()
-
Create a set for the
Bidi_Controlproperty, using compiled data.factory - CodePointSetData.bidiControlWithProvider(DataProvider provider)
-
Create a set for the
Bidi_Controlproperty, using a particular data source.factory - CodePointSetData.bidiMirrored()
-
Create a set for the
Bidi_Mirroredproperty, using compiled data.factory - CodePointSetData.bidiMirroredWithProvider(DataProvider provider)
-
Create a set for the
Bidi_Mirroredproperty, using a particular data source.factory - CodePointSetData.blank()
-
Create a set for the
Blankproperty, using compiled data.factory - CodePointSetData.blankWithProvider(DataProvider provider)
-
Create a set for the
Blankproperty, using a particular data source.factory - CodePointSetData.cased()
-
Create a set for the
Casedproperty, using compiled data.factory - CodePointSetData.casedWithProvider(DataProvider provider)
-
Create a set for the
Casedproperty, using a particular data source.factory - CodePointSetData.caseIgnorable()
-
Create a set for the
Case_Ignorableproperty, using compiled data.factory - CodePointSetData.caseIgnorableWithProvider(DataProvider provider)
-
Create a set for the
Case_Ignorableproperty, using a particular data source.factory - CodePointSetData.caseSensitive()
-
Create a set for the
Case_Sensitiveproperty, using compiled data.factory - CodePointSetData.caseSensitiveWithProvider(DataProvider provider)
-
Create a set for the
Case_Sensitiveproperty, using a particular data source.factory - CodePointSetData.changesWhenCasefolded()
-
Create a set for the
Changes_When_Casefoldedproperty, using compiled data.factory - CodePointSetData.changesWhenCasefoldedWithProvider(DataProvider provider)
-
Create a set for the
Changes_When_Casefoldedproperty, using a particular data source.factory - CodePointSetData.changesWhenCasemapped()
-
Create a set for the
Changes_When_Casemappedproperty, using compiled data.factory - CodePointSetData.changesWhenCasemappedWithProvider(DataProvider provider)
-
Create a set for the
Changes_When_Casemappedproperty, using a particular data source.factory - CodePointSetData.changesWhenLowercased()
-
Create a set for the
Changes_When_Lowercasedproperty, using compiled data.factory - CodePointSetData.changesWhenLowercasedWithProvider(DataProvider provider)
-
Create a set for the
Changes_When_Lowercasedproperty, using a particular data source.factory - CodePointSetData.changesWhenNfkcCasefolded()
-
Create a set for the
Changes_When_Nfkc_Casefoldedproperty, using compiled data.factory - CodePointSetData.changesWhenNfkcCasefoldedWithProvider(DataProvider provider)
-
Create a set for the
Changes_When_Nfkc_Casefoldedproperty, using a particular data source.factory - CodePointSetData.changesWhenTitlecased()
-
Create a set for the
Changes_When_Titlecasedproperty, using compiled data.factory - CodePointSetData.changesWhenTitlecasedWithProvider(DataProvider provider)
-
Create a set for the
Changes_When_Titlecasedproperty, using a particular data source.factory - CodePointSetData.changesWhenUppercased()
-
Create a set for the
Changes_When_Uppercasedproperty, using compiled data.factory - CodePointSetData.changesWhenUppercasedWithProvider(DataProvider provider)
-
Create a set for the
Changes_When_Uppercasedproperty, using a particular data source.factory - CodePointSetData.dash()
-
Create a set for the
Dashproperty, using compiled data.factory - CodePointSetData.dashWithProvider(DataProvider provider)
-
Create a set for the
Dashproperty, using a particular data source.factory - CodePointSetData.defaultIgnorableCodePoint()
-
Create a set for the
Default_Ignorable_Code_Pointproperty, using compiled data.factory - CodePointSetData.defaultIgnorableCodePointWithProvider(DataProvider provider)
-
Create a set for the
Default_Ignorable_Code_Pointproperty, using a particular data source.factory - CodePointSetData.deprecated()
-
Create a set for the
Deprecatedproperty, using compiled data.factory - CodePointSetData.deprecatedWithProvider(DataProvider provider)
-
Create a set for the
Deprecatedproperty, using a particular data source.factory - CodePointSetData.diacritic()
-
Create a set for the
Diacriticproperty, using compiled data.factory - CodePointSetData.diacriticWithProvider(DataProvider provider)
-
Create a set for the
Diacriticproperty, using a particular data source.factory - CodePointSetData.emoji()
-
Create a set for the
Emojiproperty, using compiled data.factory - CodePointSetData.emojiComponent()
-
Create a set for the
Emoji_Componentproperty, using compiled data.factory - CodePointSetData.emojiComponentWithProvider(DataProvider provider)
-
Create a set for the
Emoji_Componentproperty, using a particular data source.factory - CodePointSetData.emojiModifier()
-
Create a set for the
Emoji_Modifierproperty, using compiled data.factory - CodePointSetData.emojiModifierBase()
-
Create a set for the
Emoji_Modifier_Baseproperty, using compiled data.factory - CodePointSetData.emojiModifierBaseWithProvider(DataProvider provider)
-
Create a set for the
Emoji_Modifier_Baseproperty, using a particular data source.factory - CodePointSetData.emojiModifierWithProvider(DataProvider provider)
-
Create a set for the
Emoji_Modifierproperty, using a particular data source.factory - CodePointSetData.emojiPresentation()
-
Create a set for the
Emoji_Presentationproperty, using compiled data.factory - CodePointSetData.emojiPresentationWithProvider(DataProvider provider)
-
Create a set for the
Emoji_Presentationproperty, using a particular data source.factory - CodePointSetData.emojiWithProvider(DataProvider provider)
-
Create a set for the
Emojiproperty, using a particular data source.factory - CodePointSetData.extendedPictographic()
-
Create a set for the
Extended_Pictographicproperty, using compiled data.factory - CodePointSetData.extendedPictographicWithProvider(DataProvider provider)
-
Create a set for the
Extended_Pictographicproperty, using a particular data source.factory - CodePointSetData.extender()
-
Create a set for the
Extenderproperty, using compiled data.factory - CodePointSetData.extenderWithProvider(DataProvider provider)
-
Create a set for the
Extenderproperty, using a particular data source.factory - CodePointSetData.forEcma262(String propertyName)
-
See the Rust documentation for
new_for_ecma262for more information.factory - CodePointSetData.forEcma262WithProvider(DataProvider provider, String propertyName)
-
See the Rust documentation for
new_for_ecma262for more information.factory - CodePointSetData.fullCompositionExclusion()
-
Create a set for the
Full_Composition_Exclusionproperty, using compiled data.factory - CodePointSetData.fullCompositionExclusionWithProvider(DataProvider provider)
-
Create a set for the
Full_Composition_Exclusionproperty, using a particular data source.factory - CodePointSetData.generalCategoryGroup(GeneralCategoryGroup group)
-
Produces a set for obtaining General Category Group values
which is a mask with the same format as the
U_GC_XX_MASKmask in ICU4C, using compiled data.factory - CodePointSetData.generalCategoryGroupWithProvider(DataProvider provider, int group)
-
Produces a set for obtaining General Category Group values
which is a mask with the same format as the
U_GC_XX_MASKmask in ICU4C, using a provided data source.factory - CodePointSetData.graph()
-
Create a set for the
Graphproperty, using compiled data.factory - CodePointSetData.graphemeBase()
-
Create a set for the
Grapheme_Baseproperty, using compiled data.factory - CodePointSetData.graphemeBaseWithProvider(DataProvider provider)
-
Create a set for the
Grapheme_Baseproperty, using a particular data source.factory - CodePointSetData.graphemeExtend()
-
Create a set for the
Grapheme_Extendproperty, using compiled data.factory - CodePointSetData.graphemeExtendWithProvider(DataProvider provider)
-
Create a set for the
Grapheme_Extendproperty, using a particular data source.factory - CodePointSetData.graphemeLink()
-
Create a set for the
Grapheme_Linkproperty, using compiled data.factory - CodePointSetData.graphemeLinkWithProvider(DataProvider provider)
-
Create a set for the
Grapheme_Linkproperty, using a particular data source.factory - CodePointSetData.graphWithProvider(DataProvider provider)
-
Create a set for the
Graphproperty, using a particular data source.factory - CodePointSetData.hexDigit()
-
Create a set for the
Hex_Digitproperty, using compiled data.factory - CodePointSetData.hexDigitWithProvider(DataProvider provider)
-
Create a set for the
Hex_Digitproperty, using a particular data source.factory - CodePointSetData.hyphen()
-
Create a set for the
Hyphenproperty, using compiled data.factory - CodePointSetData.hyphenWithProvider(DataProvider provider)
-
Create a set for the
Hyphenproperty, using a particular data source.factory - CodePointSetData.idCompatMathContinue()
-
Create a set for the
ID_Compat_Math_Continueproperty, using compiled data.factory - CodePointSetData.idCompatMathContinueWithProvider(DataProvider provider)
-
Create a set for the
ID_Compat_Math_Continueproperty, using a particular data source.factory - CodePointSetData.idCompatMathStart()
-
Create a set for the
ID_Compat_Math_Startproperty, using compiled data.factory - CodePointSetData.idCompatMathStartWithProvider(DataProvider provider)
-
Create a set for the
ID_Compat_Math_Startproperty, using a particular data source.factory - CodePointSetData.idContinue()
-
Create a set for the
Id_Continueproperty, using compiled data.factory - CodePointSetData.idContinueWithProvider(DataProvider provider)
-
Create a set for the
Id_Continueproperty, using a particular data source.factory - CodePointSetData.ideographic()
-
Create a set for the
Ideographicproperty, using compiled data.factory - CodePointSetData.ideographicWithProvider(DataProvider provider)
-
Create a set for the
Ideographicproperty, using a particular data source.factory - CodePointSetData.idsBinaryOperator()
-
Create a set for the
Ids_Binary_Operatorproperty, using compiled data.factory - CodePointSetData.idsBinaryOperatorWithProvider(DataProvider provider)
-
Create a set for the
Ids_Binary_Operatorproperty, using a particular data source.factory - CodePointSetData.idStart()
-
Create a set for the
Id_Startproperty, using compiled data.factory - CodePointSetData.idStartWithProvider(DataProvider provider)
-
Create a set for the
Id_Startproperty, using a particular data source.factory - CodePointSetData.idsTrinaryOperator()
-
Create a set for the
Ids_Trinary_Operatorproperty, using compiled data.factory - CodePointSetData.idsTrinaryOperatorWithProvider(DataProvider provider)
-
Create a set for the
Ids_Trinary_Operatorproperty, using a particular data source.factory - CodePointSetData.idsUnaryOperator()
-
Create a set for the
Ids_Unary_Operatorproperty, using compiled data.factory - CodePointSetData.idsUnaryOperatorWithProvider(DataProvider provider)
-
Create a set for the
Ids_Unary_Operatorproperty, using a particular data source.factory - CodePointSetData.joinControl()
-
Create a set for the
Join_Controlproperty, using compiled data.factory - CodePointSetData.joinControlWithProvider(DataProvider provider)
-
Create a set for the
Join_Controlproperty, using a particular data source.factory - CodePointSetData.logicalOrderException()
-
Create a set for the
Logical_Order_Exceptionproperty, using compiled data.factory - CodePointSetData.logicalOrderExceptionWithProvider(DataProvider provider)
-
Create a set for the
Logical_Order_Exceptionproperty, using a particular data source.factory - CodePointSetData.lowercase()
-
Create a set for the
Lowercaseproperty, using compiled data.factory - CodePointSetData.lowercaseWithProvider(DataProvider provider)
-
Create a set for the
Lowercaseproperty, using a particular data source.factory - CodePointSetData.math()
-
Create a set for the
Mathproperty, using compiled data.factory - CodePointSetData.mathWithProvider(DataProvider provider)
-
Create a set for the
Mathproperty, using a particular data source.factory - CodePointSetData.modifierCombiningMark()
-
Create a set for the
Modifier_Combining_markproperty, using compiled data.factory - CodePointSetData.modifierCombiningMarkWithProvider(DataProvider provider)
-
Create a set for the
Modifier_Combining_markproperty, using a particular data source.factory - CodePointSetData.nfcInert()
-
Create a set for the
Nfc_Inertproperty, using compiled data.factory - CodePointSetData.nfcInertWithProvider(DataProvider provider)
-
Create a set for the
Nfc_Inertproperty, using a particular data source.factory - CodePointSetData.nfdInert()
-
Create a set for the
Nfd_Inertproperty, using compiled data.factory - CodePointSetData.nfdInertWithProvider(DataProvider provider)
-
Create a set for the
Nfd_Inertproperty, using a particular data source.factory - CodePointSetData.nfkcInert()
-
Create a set for the
Nfkc_Inertproperty, using compiled data.factory - CodePointSetData.nfkcInertWithProvider(DataProvider provider)
-
Create a set for the
Nfkc_Inertproperty, using a particular data source.factory - CodePointSetData.nfkdInert()
-
Create a set for the
Nfkd_Inertproperty, using compiled data.factory - CodePointSetData.nfkdInertWithProvider(DataProvider provider)
-
Create a set for the
Nfkd_Inertproperty, using a particular data source.factory - CodePointSetData.noncharacterCodePoint()
-
Create a set for the
Noncharacter_Code_Pointproperty, using compiled data.factory - CodePointSetData.noncharacterCodePointWithProvider(DataProvider provider)
-
Create a set for the
Noncharacter_Code_Pointproperty, using a particular data source.factory - CodePointSetData.patternSyntax()
-
Create a set for the
Pattern_Syntaxproperty, using compiled data.factory - CodePointSetData.patternSyntaxWithProvider(DataProvider provider)
-
Create a set for the
Pattern_Syntaxproperty, using a particular data source.factory - CodePointSetData.patternWhiteSpace()
-
Create a set for the
Pattern_White_Spaceproperty, using compiled data.factory - CodePointSetData.patternWhiteSpaceWithProvider(DataProvider provider)
-
Create a set for the
Pattern_White_Spaceproperty, using a particular data source.factory - CodePointSetData.prependedConcatenationMark()
-
Create a set for the
Prepended_Concatenation_Markproperty, using compiled data.factory - CodePointSetData.prependedConcatenationMarkWithProvider(DataProvider provider)
-
Create a set for the
Prepended_Concatenation_Markproperty, using a particular data source.factory - CodePointSetData.print()
-
Create a set for the
Printproperty, using compiled data.factory - CodePointSetData.printWithProvider(DataProvider provider)
-
Create a set for the
Printproperty, using a particular data source.factory - CodePointSetData.quotationMark()
-
Create a set for the
Quotation_Markproperty, using compiled data.factory - CodePointSetData.quotationMarkWithProvider(DataProvider provider)
-
Create a set for the
Quotation_Markproperty, using a particular data source.factory - CodePointSetData.radical()
-
Create a set for the
Radicalproperty, using compiled data.factory - CodePointSetData.radicalWithProvider(DataProvider provider)
-
Create a set for the
Radicalproperty, using a particular data source.factory - CodePointSetData.regionalIndicator()
-
Create a set for the
Regional_Indicatorproperty, using compiled data.factory - CodePointSetData.regionalIndicatorWithProvider(DataProvider provider)
-
Create a set for the
Regional_Indicatorproperty, using a particular data source.factory - CodePointSetData.segmentStarter()
-
Create a set for the
Segment_Starterproperty, using compiled data.factory - CodePointSetData.segmentStarterWithProvider(DataProvider provider)
-
Create a set for the
Segment_Starterproperty, using a particular data source.factory - CodePointSetData.sentenceTerminal()
-
Create a set for the
Sentence_Terminalproperty, using compiled data.factory - CodePointSetData.sentenceTerminalWithProvider(DataProvider provider)
-
Create a set for the
Sentence_Terminalproperty, using a particular data source.factory - CodePointSetData.softDotted()
-
Create a set for the
Soft_Dottedproperty, using compiled data.factory - CodePointSetData.softDottedWithProvider(DataProvider provider)
-
Create a set for the
Soft_Dottedproperty, using a particular data source.factory - CodePointSetData.terminalPunctuation()
-
Create a set for the
Terminal_Punctuationproperty, using compiled data.factory - CodePointSetData.terminalPunctuationWithProvider(DataProvider provider)
-
Create a set for the
Terminal_Punctuationproperty, using a particular data source.factory - CodePointSetData.unifiedIdeograph()
-
Create a set for the
Unified_Ideographproperty, using compiled data.factory - CodePointSetData.unifiedIdeographWithProvider(DataProvider provider)
-
Create a set for the
Unified_Ideographproperty, using a particular data source.factory - CodePointSetData.uppercase()
-
Create a set for the
Uppercaseproperty, using compiled data.factory - CodePointSetData.uppercaseWithProvider(DataProvider provider)
-
Create a set for the
Uppercaseproperty, using a particular data source.factory - CodePointSetData.variationSelector()
-
Create a set for the
Variation_Selectorproperty, using compiled data.factory - CodePointSetData.variationSelectorWithProvider(DataProvider provider)
-
Create a set for the
Variation_Selectorproperty, using a particular data source.factory - CodePointSetData.whiteSpace()
-
Create a set for the
White_Spaceproperty, using compiled data.factory - CodePointSetData.whiteSpaceWithProvider(DataProvider provider)
-
Create a set for the
White_Spaceproperty, using a particular data source.factory - CodePointSetData.xdigit()
-
Create a set for the
Xdigitproperty, using compiled data.factory - CodePointSetData.xdigitWithProvider(DataProvider provider)
-
Create a set for the
Xdigitproperty, using a particular data source.factory - CodePointSetData.xidContinue()
-
Create a set for the
Xid_Continueproperty, using compiled data.factory - CodePointSetData.xidContinueWithProvider(DataProvider provider)
-
Create a set for the
Xid_Continueproperty, using a particular data source.factory - CodePointSetData.xidStart()
-
Create a set for the
Xid_Startproperty, using compiled data.factory - CodePointSetData.xidStartWithProvider(DataProvider provider)
-
Create a set for the
Xid_Startproperty, using a particular data source.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
contains(
Rune cp) → bool - Checks whether the code point is in the set.
-
iterRanges(
) → CodePointRangeIterator - Produces an iterator over ranges of code points contained in this set
-
iterRangesComplemented(
) → CodePointRangeIterator - Produces an iterator over ranges of code points not contained in this set
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
alnumForChar(
Rune ch) → bool -
Get the
Alnumvalue for a given character, using compiled data -
alphabeticForChar(
Rune ch) → bool -
Get the
Alphabeticvalue for a given character, using compiled data -
asciiHexDigitForChar(
Rune ch) → bool -
Get the
Ascii_Hex_Digitvalue for a given character, using compiled data -
bidiControlForChar(
Rune ch) → bool -
Get the
Bidi_Controlvalue for a given character, using compiled data -
bidiMirroredForChar(
Rune ch) → bool -
Get the
Bidi_Mirroredvalue for a given character, using compiled data -
blankForChar(
Rune ch) → bool -
Get the
Blankvalue for a given character, using compiled data -
casedForChar(
Rune ch) → bool -
Get the
Casedvalue for a given character, using compiled data -
caseIgnorableForChar(
Rune ch) → bool -
Get the
Case_Ignorablevalue for a given character, using compiled data -
caseSensitiveForChar(
Rune ch) → bool -
Get the
Case_Sensitivevalue for a given character, using compiled data -
changesWhenCasefoldedForChar(
Rune ch) → bool -
Get the
Changes_When_Casefoldedvalue for a given character, using compiled data -
changesWhenCasemappedForChar(
Rune ch) → bool -
Get the
Changes_When_Casemappedvalue for a given character, using compiled data -
changesWhenLowercasedForChar(
Rune ch) → bool -
Get the
Changes_When_Lowercasedvalue for a given character, using compiled data -
changesWhenNfkcCasefoldedForChar(
Rune ch) → bool -
Get the
Changes_When_Nfkc_Casefoldedvalue for a given character, using compiled data -
changesWhenTitlecasedForChar(
Rune ch) → bool -
Get the
Changes_When_Titlecasedvalue for a given character, using compiled data -
changesWhenUppercasedForChar(
Rune ch) → bool -
Get the
Changes_When_Uppercasedvalue for a given character, using compiled data -
dashForChar(
Rune ch) → bool -
Get the
Dashvalue for a given character, using compiled data -
defaultIgnorableCodePointForChar(
Rune ch) → bool -
Get the
Default_Ignorable_Code_Pointvalue for a given character, using compiled data -
deprecatedForChar(
Rune ch) → bool -
Get the
Deprecatedvalue for a given character, using compiled data -
diacriticForChar(
Rune ch) → bool -
Get the
Diacriticvalue for a given character, using compiled data -
emojiComponentForChar(
Rune ch) → bool -
Get the
Emoji_Componentvalue for a given character, using compiled data -
emojiForChar(
Rune ch) → bool -
Get the
Emojivalue for a given character, using compiled data -
emojiModifierBaseForChar(
Rune ch) → bool -
Get the
Emoji_Modifier_Basevalue for a given character, using compiled data -
emojiModifierForChar(
Rune ch) → bool -
Get the
Emoji_Modifiervalue for a given character, using compiled data -
emojiPresentationForChar(
Rune ch) → bool -
Get the
Emoji_Presentationvalue for a given character, using compiled data -
extendedPictographicForChar(
Rune ch) → bool -
Get the
Extended_Pictographicvalue for a given character, using compiled data -
extenderForChar(
Rune ch) → bool -
Get the
Extendervalue for a given character, using compiled data -
fullCompositionExclusionForChar(
Rune ch) → bool -
Get the
Full_Composition_Exclusionvalue for a given character, using compiled data -
graphemeBaseForChar(
Rune ch) → bool -
Get the
Grapheme_Basevalue for a given character, using compiled data -
graphemeExtendForChar(
Rune ch) → bool -
Get the
Grapheme_Extendvalue for a given character, using compiled data -
graphemeLinkForChar(
Rune ch) → bool -
Get the
Grapheme_Linkvalue for a given character, using compiled data -
graphForChar(
Rune ch) → bool -
Get the
Graphvalue for a given character, using compiled data -
hexDigitForChar(
Rune ch) → bool -
Get the
Hex_Digitvalue for a given character, using compiled data -
hyphenForChar(
Rune ch) → bool -
Get the
Hyphenvalue for a given character, using compiled data -
idCompatMathContinueForChar(
Rune ch) → bool -
Get the
ID_Compat_Math_Continuevalue for a given character, using compiled data -
idCompatMathStartForChar(
Rune ch) → bool -
Get the
ID_Compat_Math_Startvalue for a given character, using compiled data -
idContinueForChar(
Rune ch) → bool -
Get the
Id_Continuevalue for a given character, using compiled data -
ideographicForChar(
Rune ch) → bool -
Get the
Ideographicvalue for a given character, using compiled data -
idsBinaryOperatorForChar(
Rune ch) → bool -
Get the
Ids_Binary_Operatorvalue for a given character, using compiled data -
idStartForChar(
Rune ch) → bool -
Get the
Id_Startvalue for a given character, using compiled data -
idsTrinaryOperatorForChar(
Rune ch) → bool -
Get the
Ids_Trinary_Operatorvalue for a given character, using compiled data -
idsUnaryOperatorForChar(
Rune ch) → bool -
Get the
Ids_Unary_Operatorvalue for a given character, using compiled data -
joinControlForChar(
Rune ch) → bool -
Get the
Join_Controlvalue for a given character, using compiled data -
logicalOrderExceptionForChar(
Rune ch) → bool -
Get the
Logical_Order_Exceptionvalue for a given character, using compiled data -
lowercaseForChar(
Rune ch) → bool -
Get the
Lowercasevalue for a given character, using compiled data -
mathForChar(
Rune ch) → bool -
Get the
Mathvalue for a given character, using compiled data -
modifierCombiningMarkForChar(
Rune ch) → bool -
Get the
Modifier_Combining_markvalue for a given character, using compiled data -
nfcInertForChar(
Rune ch) → bool -
Get the
Nfc_Inertvalue for a given character, using compiled data -
nfdInertForChar(
Rune ch) → bool -
Get the
Nfd_Inertvalue for a given character, using compiled data -
nfkcInertForChar(
Rune ch) → bool -
Get the
Nfkc_Inertvalue for a given character, using compiled data -
nfkdInertForChar(
Rune ch) → bool -
Get the
Nfkd_Inertvalue for a given character, using compiled data -
noncharacterCodePointForChar(
Rune ch) → bool -
Get the
Noncharacter_Code_Pointvalue for a given character, using compiled data -
patternSyntaxForChar(
Rune ch) → bool -
Get the
Pattern_Syntaxvalue for a given character, using compiled data -
patternWhiteSpaceForChar(
Rune ch) → bool -
Get the
Pattern_White_Spacevalue for a given character, using compiled data -
prependedConcatenationMarkForChar(
Rune ch) → bool -
Get the
Prepended_Concatenation_Markvalue for a given character, using compiled data -
printForChar(
Rune ch) → bool -
Get the
Printvalue for a given character, using compiled data -
quotationMarkForChar(
Rune ch) → bool -
Get the
Quotation_Markvalue for a given character, using compiled data -
radicalForChar(
Rune ch) → bool -
Get the
Radicalvalue for a given character, using compiled data -
regionalIndicatorForChar(
Rune ch) → bool -
Get the
Regional_Indicatorvalue for a given character, using compiled data -
segmentStarterForChar(
Rune ch) → bool -
Get the
Segment_Startervalue for a given character, using compiled data -
sentenceTerminalForChar(
Rune ch) → bool -
Get the
Sentence_Terminalvalue for a given character, using compiled data -
softDottedForChar(
Rune ch) → bool -
Get the
Soft_Dottedvalue for a given character, using compiled data -
terminalPunctuationForChar(
Rune ch) → bool -
Get the
Terminal_Punctuationvalue for a given character, using compiled data -
unifiedIdeographForChar(
Rune ch) → bool -
Get the
Unified_Ideographvalue for a given character, using compiled data -
uppercaseForChar(
Rune ch) → bool -
Get the
Uppercasevalue for a given character, using compiled data -
variationSelectorForChar(
Rune ch) → bool -
Get the
Variation_Selectorvalue for a given character, using compiled data -
whiteSpaceForChar(
Rune ch) → bool -
Get the
White_Spacevalue for a given character, using compiled data -
xdigitForChar(
Rune ch) → bool -
Get the
Xdigitvalue for a given character, using compiled data -
xidContinueForChar(
Rune ch) → bool -
Get the
Xid_Continuevalue for a given character, using compiled data -
xidStartForChar(
Rune ch) → bool -
Get the
Xid_Startvalue for a given character, using compiled data