Collator class final
See the Rust documentation for Collator for more information.
- Implemented types
Constructors
- Collator(Locale locale, CollatorOptions options)
-
Construct a new Collator instance using compiled data.
factory
- Collator.createWithProvider(DataProvider provider, Locale locale, CollatorOptions options)
-
Construct a new Collator instance using a particular data source.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resolvedOptions → CollatorResolvedOptions
-
The resolved options showing how the default options, the requested options,
and the options from locale data were combined. None of the struct fields
will have
Autoas the value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
compare(
String left, String right) → int - Compare two strings.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited