EmojiSetData class final
An ICU4X Unicode Set Property object, capable of querying whether a code point is contained in a set based on a Unicode property.
See the Rust documentation for properties for more information.
See the Rust documentation for EmojiSetData for more information.
See the Rust documentation for new for more information.
See the Rust documentation for EmojiSetDataBorrowed for more information.
- Implemented types
Constructors
- EmojiSetData.basic()
-
Create a map for the
Basic_Emojiproperty, using compiled data.factory - EmojiSetData.basicWithProvider(DataProvider provider)
-
Create a map for the
Basic_Emojiproperty, using a particular data source.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
contains(
Rune cp) → bool - Checks whether the code point is in the set.
-
containsStr(
String s) → bool - Checks whether the string is in the set.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited