GeneralCategoryGroup class final
A mask that is capable of representing groups of General_Category values.
See the Rust documentation for GeneralCategoryGroup for more information.
Constructors
- GeneralCategoryGroup({required int mask})
Properties
Methods
-
complement(
) → GeneralCategoryGroup -
See the Rust documentation for
complementfor more information. -
contains(
GeneralCategory val) → bool -
See the Rust documentation for
containsfor more information. -
intersection(
GeneralCategoryGroup other) → GeneralCategoryGroup -
See the Rust documentation for
intersectionfor more information. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
union(
GeneralCategoryGroup other) → GeneralCategoryGroup -
See the Rust documentation for
unionfor more information.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
all(
) → GeneralCategoryGroup -
See the Rust documentation for
allfor more information. -
casedLetter(
) → GeneralCategoryGroup -
See the Rust documentation for
CasedLetterfor more information. -
empty(
) → GeneralCategoryGroup -
See the Rust documentation for
emptyfor more information. -
letter(
) → GeneralCategoryGroup -
See the Rust documentation for
Letterfor more information. -
mark(
) → GeneralCategoryGroup -
See the Rust documentation for
Markfor more information. -
number(
) → GeneralCategoryGroup -
See the Rust documentation for
Numberfor more information. -
other(
) → GeneralCategoryGroup -
See the Rust documentation for
Letterfor more information. -
punctuation(
) → GeneralCategoryGroup -
See the Rust documentation for
Punctuationfor more information. -
separator(
) → GeneralCategoryGroup -
See the Rust documentation for
Otherfor more information. -
symbol(
) → GeneralCategoryGroup -
See the Rust documentation for
Symbolfor more information.