LineBreak enum
See the Rust documentation for LineBreak for more information.
Values
- unknown → const LineBreak
-
See the Rust documentation for
Unknownfor more information. - ambiguous → const LineBreak
-
See the Rust documentation for
Ambiguousfor more information. - alphabetic → const LineBreak
-
See the Rust documentation for
Alphabeticfor more information. - breakBoth → const LineBreak
-
See the Rust documentation for
BreakBothfor more information. - breakAfter → const LineBreak
-
See the Rust documentation for
BreakAfterfor more information. - breakBefore → const LineBreak
-
See the Rust documentation for
BreakBeforefor more information. - mandatoryBreak → const LineBreak
-
See the Rust documentation for
MandatoryBreakfor more information. - contingentBreak → const LineBreak
-
See the Rust documentation for
ContingentBreakfor more information. - closePunctuation → const LineBreak
-
See the Rust documentation for
ClosePunctuationfor more information. - combiningMark → const LineBreak
-
See the Rust documentation for
CombiningMarkfor more information. - carriageReturn → const LineBreak
-
See the Rust documentation for
CarriageReturnfor more information. - exclamation → const LineBreak
-
See the Rust documentation for
Exclamationfor more information. - glue → const LineBreak
-
See the Rust documentation for
Gluefor more information. - hyphen → const LineBreak
-
See the Rust documentation for
Hyphenfor more information. - ideographic → const LineBreak
-
See the Rust documentation for
Ideographicfor more information. - inseparable → const LineBreak
-
See the Rust documentation for
Inseparablefor more information. - infixNumeric → const LineBreak
-
See the Rust documentation for
InfixNumericfor more information. - lineFeed → const LineBreak
-
See the Rust documentation for
LineFeedfor more information. - nonstarter → const LineBreak
-
See the Rust documentation for
Nonstarterfor more information. - numeric → const LineBreak
-
See the Rust documentation for
Numericfor more information. - openPunctuation → const LineBreak
-
See the Rust documentation for
OpenPunctuationfor more information. - postfixNumeric → const LineBreak
-
See the Rust documentation for
PostfixNumericfor more information. - prefixNumeric → const LineBreak
-
See the Rust documentation for
PrefixNumericfor more information. - quotation → const LineBreak
-
See the Rust documentation for
Quotationfor more information. - complexContext → const LineBreak
-
See the Rust documentation for
ComplexContextfor more information. - surrogate → const LineBreak
-
See the Rust documentation for
Surrogatefor more information. - space → const LineBreak
-
See the Rust documentation for
Spacefor more information. - breakSymbols → const LineBreak
-
See the Rust documentation for
BreakSymbolsfor more information. - zwSpace → const LineBreak
-
See the Rust documentation for
ZWSpacefor more information. - nextLine → const LineBreak
-
See the Rust documentation for
NextLinefor more information. - wordJoiner → const LineBreak
-
See the Rust documentation for
WordJoinerfor more information. - h2 → const LineBreak
-
See the Rust documentation for
H2for more information. - h3 → const LineBreak
-
See the Rust documentation for
H3for more information. - jl → const LineBreak
-
See the Rust documentation for
JLfor more information. - jt → const LineBreak
-
See the Rust documentation for
JTfor more information. - jv → const LineBreak
-
See the Rust documentation for
JVfor more information. - closeParenthesis → const LineBreak
-
See the Rust documentation for
CloseParenthesisfor more information. - conditionalJapaneseStarter → const LineBreak
-
See the Rust documentation for
ConditionalJapaneseStarterfor more information. - hebrewLetter → const LineBreak
-
See the Rust documentation for
HebrewLetterfor more information. - regionalIndicator → const LineBreak
-
See the Rust documentation for
RegionalIndicatorfor more information. - eBase → const LineBreak
-
See the Rust documentation for
EBasefor more information. - eModifier → const LineBreak
-
See the Rust documentation for
EModifierfor more information. - zwj → const LineBreak
-
See the Rust documentation for
ZWJfor more information. - aksara → const LineBreak
-
See the Rust documentation for
Aksarafor more information. - aksaraPrebase → const LineBreak
-
See the Rust documentation for
AksaraPrebasefor more information. - aksaraStart → const LineBreak
-
See the Rust documentation for
AksaraStartfor more information. - viramaFinal → const LineBreak
-
See the Rust documentation for
ViramaFinalfor more information. - virama → const LineBreak
-
See the Rust documentation for
Viramafor more information. - unambiguousHyphen → const LineBreak
-
See the Rust documentation for
UnambiguousHyphenfor more information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
longName(
) → String? - Get the "long" name of this property value (returns empty if property value is unknown)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortName(
) → String? - Get the "short" name of this property value (returns empty if property value is unknown)
-
toIntegerValue(
) → int - Convert to an integer value usable with ICU4C and CodePointMapData
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forChar(
Rune ch) → LineBreak -
See the Rust documentation for
for_charfor more information. -
fromIntegerValue(
int other) → LineBreak? - Convert from an integer value from ICU4C or CodePointMapData