LocaleFallbacker class final
An object that runs the ICU4X locale fallback algorithm.
See the Rust documentation for LocaleFallbacker for more information.
- Implemented types
Constructors
- LocaleFallbacker()
-
Creates a new
LocaleFallbackerfrom compiled data.factory - LocaleFallbacker.withoutData()
-
Creates a new
LocaleFallbackerwithout data for limited functionality.factory - LocaleFallbacker.withProvider(DataProvider provider)
-
Creates a new
LocaleFallbackerfrom a data provider.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
forConfig(
LocaleFallbackConfig config) → LocaleFallbackerWithConfig -
Associates this
LocaleFallbackerwith configuration options. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited