NumericType enum

See the Rust documentation for NumericType for more information.

Inheritance
Available extensions

Values

none → const NumericType

See the Rust documentation for None for more information.

decimal → const NumericType

See the Rust documentation for Decimal for more information.

digit → const NumericType

See the Rust documentation for Digit for more information.

numeric → const NumericType

See the Rust documentation for Numeric for more information.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

longName() String?
Get the "long" name of this property value (returns empty if property value is unknown)
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shortName() String?
Get the "short" name of this property value (returns empty if property value is unknown)
toIntegerValue() int
Convert to an integer value usable with ICU4C and CodePointMapData
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

forChar(Rune ch) NumericType
See the Rust documentation for for_char for more information.
fromIntegerValue(int other) NumericType?
Convert from an integer value from ICU4C or CodePointMapData
fromString(String s) NumericType?
Creates a NumericType from a string.

Constants

values → const List<NumericType>
A constant List of the values in this enum, in order of their declaration.