PluralCategories class final

See the Rust documentation for categories for more information.

Properties

few bool
final
hashCode int
The hash code for this object.
no setteroverride
many bool
final
one bool
final
other bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
two bool
final
zero bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override