PropertyValueNameToEnumMapper class final
A type capable of looking up a property value from a string name.
See the Rust documentation for PropertyParser for more information.
See the Rust documentation for PropertyParserBorrowed for more information.
See the Rust documentation for new for more information.
- Implemented types
Constructors
- PropertyValueNameToEnumMapper.bidiClass()
-
Create a name-to-enum mapper for the
Bidi_Classproperty, using compiled data.factory - PropertyValueNameToEnumMapper.bidiClassWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Bidi_Classproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.eastAsianWidth()
-
Create a name-to-enum mapper for the
East_Asian_Widthproperty, using compiled data.factory - PropertyValueNameToEnumMapper.eastAsianWidthWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
East_Asian_Widthproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.generalCategory()
-
Create a name-to-enum mapper for the
General_Categoryproperty, using compiled data.factory - PropertyValueNameToEnumMapper.generalCategoryWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
General_Categoryproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.graphemeClusterBreak()
-
Create a name-to-enum mapper for the
Grapheme_Cluster_Breakproperty, using compiled data.factory - PropertyValueNameToEnumMapper.graphemeClusterBreakWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Grapheme_Cluster_Breakproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.hangulSyllableType()
-
Create a name-to-enum mapper for the
Hangul_Syllable_Typeproperty, using compiled data.factory - PropertyValueNameToEnumMapper.hangulSyllableTypeWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Hangul_Syllable_Typeproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.indicSyllabicCategory()
-
Create a name-to-enum mapper for the
Indic_Syllabic_Categoryproperty, using compiled data.factory - PropertyValueNameToEnumMapper.indicSyllabicCategoryWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Indic_Syllabic_Categoryproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.joiningGroup()
-
Create a name-to-enum mapper for the
JoiningGroupproperty, using compiled data.factory - PropertyValueNameToEnumMapper.joiningGroupWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
JoiningGroupproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.joiningType()
-
Create a name-to-enum mapper for the
JoiningTypeproperty, using compiled data.factory - PropertyValueNameToEnumMapper.joiningTypeWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
JoiningTypeproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.lineBreak()
-
Create a name-to-enum mapper for the
Line_Breakproperty, using compiled data.factory - PropertyValueNameToEnumMapper.lineBreakWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Line_Breakproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.numericType()
-
Create a name-to-enum mapper for the
Numeric_Typeproperty, using compiled data.factory - PropertyValueNameToEnumMapper.numericTypeWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Numeric_Typeproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.script()
-
Create a name-to-enum mapper for the
Scriptproperty, using compiled data.factory - PropertyValueNameToEnumMapper.scriptWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Scriptproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.sentenceBreak()
-
Create a name-to-enum mapper for the
Sentence_Breakproperty, using compiled data.factory - PropertyValueNameToEnumMapper.sentenceBreakWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Sentence_Breakproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.verticalOrientation()
-
Create a name-to-enum mapper for the
Vertical_Orientationproperty, using compiled data.factory - PropertyValueNameToEnumMapper.verticalOrientationWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Vertical_Orientationproperty, using a particular data source.factory - PropertyValueNameToEnumMapper.wordBreak()
-
Create a name-to-enum mapper for the
Word_Breakproperty, using compiled data.factory - PropertyValueNameToEnumMapper.wordBreakWithProvider(DataProvider provider)
-
Create a name-to-enum mapper for the
Word_Breakproperty, using a particular data source.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getLoose(
String name) → int - Get the property value matching the given name, using loose matching
-
getStrict(
String name) → int - Get the property value matching the given name, using strict matching
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited