SentenceBreak enum
See the Rust documentation for SentenceBreak for more information.
Values
- other → const SentenceBreak
-
See the Rust documentation for
Otherfor more information. - aTerm → const SentenceBreak
-
See the Rust documentation for
ATermfor more information. - close → const SentenceBreak
-
See the Rust documentation for
Closefor more information. - format → const SentenceBreak
-
See the Rust documentation for
Formatfor more information. - lower → const SentenceBreak
-
See the Rust documentation for
Lowerfor more information. - numeric → const SentenceBreak
-
See the Rust documentation for
Numericfor more information. - oLetter → const SentenceBreak
-
See the Rust documentation for
OLetterfor more information. - sep → const SentenceBreak
-
See the Rust documentation for
Sepfor more information. - sp → const SentenceBreak
-
See the Rust documentation for
Spfor more information. - sTerm → const SentenceBreak
-
See the Rust documentation for
STermfor more information. - upper → const SentenceBreak
-
See the Rust documentation for
Upperfor more information. - cr → const SentenceBreak
-
See the Rust documentation for
CRfor more information. - extend → const SentenceBreak
-
See the Rust documentation for
Extendfor more information. - lf → const SentenceBreak
-
See the Rust documentation for
LFfor more information. - sContinue → const SentenceBreak
-
See the Rust documentation for
SContinuefor more information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
longName(
) → String? - Get the "long" name of this property value (returns empty if property value is unknown)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortName(
) → String? - Get the "short" name of this property value (returns empty if property value is unknown)
-
toIntegerValue(
) → int - Convert to an integer value usable with ICU4C and CodePointMapData
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forChar(
Rune ch) → SentenceBreak -
See the Rust documentation for
for_charfor more information. -
fromIntegerValue(
int other) → SentenceBreak? - Convert from an integer value from ICU4C or CodePointMapData
Constants
-
values
→ const List<
SentenceBreak> - A constant List of the values in this enum, in order of their declaration.