WordBreak enum
See the Rust documentation for WordBreak for more information.
Values
- other → const WordBreak
-
See the Rust documentation for
Otherfor more information. - aLetter → const WordBreak
-
See the Rust documentation for
ALetterfor more information. - format → const WordBreak
-
See the Rust documentation for
Formatfor more information. - katakana → const WordBreak
-
See the Rust documentation for
Katakanafor more information. - midLetter → const WordBreak
-
See the Rust documentation for
MidLetterfor more information. - midNum → const WordBreak
-
See the Rust documentation for
MidNumfor more information. - numeric → const WordBreak
-
See the Rust documentation for
Numericfor more information. - extendNumLet → const WordBreak
-
See the Rust documentation for
ExtendNumLetfor more information. - cr → const WordBreak
-
See the Rust documentation for
CRfor more information. - extend → const WordBreak
-
See the Rust documentation for
Extendfor more information. - lf → const WordBreak
-
See the Rust documentation for
LFfor more information. - midNumLet → const WordBreak
-
See the Rust documentation for
MidNumLetfor more information. - newline → const WordBreak
-
See the Rust documentation for
Newlinefor more information. - regionalIndicator → const WordBreak
-
See the Rust documentation for
RegionalIndicatorfor more information. - hebrewLetter → const WordBreak
-
See the Rust documentation for
HebrewLetterfor more information. - singleQuote → const WordBreak
-
See the Rust documentation for
SingleQuotefor more information. - doubleQuote → const WordBreak
-
See the Rust documentation for
DoubleQuotefor more information. - eBase → const WordBreak
-
See the Rust documentation for
EBasefor more information. - eBaseGaz → const WordBreak
-
See the Rust documentation for
EBaseGAZfor more information. - eModifier → const WordBreak
-
See the Rust documentation for
EModifierfor more information. - glueAfterZwj → const WordBreak
-
See the Rust documentation for
GlueAfterZwjfor more information. - zwj → const WordBreak
-
See the Rust documentation for
ZWJfor more information. - wSegSpace → const WordBreak
-
See the Rust documentation for
WSegSpacefor more information.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
longName(
) → String? - Get the "long" name of this property value (returns empty if property value is unknown)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shortName(
) → String? - Get the "short" name of this property value (returns empty if property value is unknown)
-
toIntegerValue(
) → int - Convert to an integer value usable with ICU4C and CodePointMapData
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forChar(
Rune ch) → WordBreak -
See the Rust documentation for
for_charfor more information. -
fromIntegerValue(
int other) → WordBreak? - Convert from an integer value from ICU4C or CodePointMapData