CodePointMapData8 class final
An ICU4X Unicode Map Property object, capable of querying whether a code point (key) to obtain the Unicode property value, for a specific Unicode property.
For properties whose values fit into 8 bits.
See the Rust documentation for properties for more information.
See the Rust documentation for CodePointMapData for more information.
See the Rust documentation for CodePointMapDataBorrowed for more information.
- Implemented types
Constructors
- CodePointMapData8.bidiClass()
-
Create a map for the
Bidi_Classproperty, using compiled data.factory - CodePointMapData8.bidiClassWithProvider(DataProvider provider)
-
Create a map for the
Bidi_Classproperty, using a particular data source.factory - CodePointMapData8.canonicalCombiningClass()
-
Create a map for the
Canonical_Combining_Classproperty, using compiled data.factory - CodePointMapData8.canonicalCombiningClassWithProvider(DataProvider provider)
-
Create a map for the
Canonical_Combining_Classproperty, using a particular data source.factory - CodePointMapData8.eastAsianWidth()
-
Create a map for the
East_Asian_Widthproperty, using compiled data.factory - CodePointMapData8.eastAsianWidthWithProvider(DataProvider provider)
-
Create a map for the
East_Asian_Widthproperty, using a particular data source.factory - CodePointMapData8.generalCategory()
-
Create a map for the
General_Categoryproperty, using compiled data.factory - CodePointMapData8.generalCategoryWithProvider(DataProvider provider)
-
Create a map for the
General_Categoryproperty, using a particular data sourcefactory - CodePointMapData8.graphemeClusterBreak()
-
Create a map for the
Grapheme_Cluster_Breakproperty, using compiled data.factory - CodePointMapData8.graphemeClusterBreakWithProvider(DataProvider provider)
-
Create a map for the
Grapheme_Cluster_Breakproperty, using a particular data source.factory - CodePointMapData8.hangulSyllableType()
-
Create a map for the
Hangul_Syllable_Typeproperty, using compiled data.factory - CodePointMapData8.hangulSyllableTypeWithProvider(DataProvider provider)
-
Create a map for the
Hangul_Syllable_Typeproperty, using a particular data source.factory - CodePointMapData8.indicSyllabicCategory()
-
Create a map for the
Indic_Syllabic_Propertyproperty, using compiled data.factory - CodePointMapData8.indicSyllabicCategoryWithProvider(DataProvider provider)
-
Create a map for the
Indic_Syllabic_Propertyproperty, using a particular data source.factory - CodePointMapData8.joiningGroup()
-
Create a map for the
Joining_Groupproperty, using compiled data.factory - CodePointMapData8.joiningGroupWithProvider(DataProvider provider)
-
Create a map for the
Joining_Groupproperty, using a particular data source.factory - CodePointMapData8.joiningType()
-
Create a map for the
Joining_Typeproperty, using compiled data.factory - CodePointMapData8.joiningTypeWithProvider(DataProvider provider)
-
Create a map for the
Joining_Typeproperty, using a particular data source.factory - CodePointMapData8.lineBreak()
-
Create a map for the
Line_Breakproperty, using compiled data.factory - CodePointMapData8.lineBreakWithProvider(DataProvider provider)
-
Create a map for the
Line_Breakproperty, using a particular data source.factory - CodePointMapData8.numericType()
-
Create a map for the
Numeric_Typeproperty, using compiled data.factory - CodePointMapData8.numericTypeWithProvider(DataProvider provider)
-
Create a map for the
Bidi_Classproperty, using a particular data source.factory - CodePointMapData8.sentenceBreak()
-
Create a map for the
Sentence_Breakproperty, using compiled data.factory - CodePointMapData8.sentenceBreakWithProvider(DataProvider provider)
-
Create a map for the
Sentence_Breakproperty, using a particular data source.factory - CodePointMapData8.verticalOrientation()
-
Create a map for the
Vertical_Orientationproperty, using compiled data.factory - CodePointMapData8.verticalOrientationWithProvider(DataProvider provider)
-
Create a map for the
Vertical_Orientationproperty, using a particular data source.factory - CodePointMapData8.wordBreak()
-
Create a map for the
Word_Breakproperty, using compiled data.factory - CodePointMapData8.wordBreakWithProvider(DataProvider provider)
-
Create a map for the
Word_Breakproperty, using a particular data source.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSetForValue(
int value) → CodePointSetData - Gets a CodePointSetData representing all entries in this map that map to the given value
-
iterRangesForGroup(
GeneralCategoryGroup group) → CodePointRangeIterator - Given a mask value (the nth bit marks property value = n), produce an iterator over ranges of code points whose property values are contained in the mask.
-
iterRangesForValue(
int value) → CodePointRangeIterator -
Produces an iterator over ranges of code points that map to
value -
iterRangesForValueComplemented(
int value) → CodePointRangeIterator -
Produces an iterator over ranges of code points that do not map to
value -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
Rune cp) → int - Gets the value for a code point.