DateFromFieldsOptions class final
🚧 This API is experimental and may experience breaking changes outside major releases.
See the Rust documentation for DateFromFieldsOptions for more information.
Constructors
- DateFromFieldsOptions({DateOverflow? overflow, DateMissingFieldsStrategy? missingFieldsStrategy})
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- missingFieldsStrategy ↔ DateMissingFieldsStrategy?
-
getter/setter pair
- overflow ↔ DateOverflow?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override