LocaleDisplayNamesFormatter class final
🚧 This API is experimental and may experience breaking changes outside major releases.
See the Rust documentation for LocaleDisplayNamesFormatter for more information.
- Implemented types
Constructors
- LocaleDisplayNamesFormatter(Locale locale, DisplayNamesOptions options)
-
🚧 This API is experimental and may experience breaking changes outside major releases.
factory
- LocaleDisplayNamesFormatter.createWithProvider(DataProvider provider, Locale locale, DisplayNamesOptions options)
-
🚧 This API is experimental and may experience breaking changes outside major releases.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
of(
Locale locale) → String - 🚧 This API is experimental and may experience breaking changes outside major releases.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited