TimeZoneInfo class final
See the Rust documentation for TimeZoneInfo for more information.
- Implemented types
Constructors
- TimeZoneInfo.utc()
-
Creates a time zone for UTC (Coordinated Universal Time).
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → TimeZone
-
See the Rust documentation for
idfor more information.no setter - offset → UtcOffset?
-
See the Rust documentation for
offsetfor more information.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zoneNameDateTime → IsoDateTime?
-
Returns the DateTime for the UTC zone name reference time
no setter
Methods
-
atDateTimeIso(
IsoDate date, Time time) → TimeZoneInfo - Sets the datetime at which to interpret the time zone for display name lookup.
-
atTimestamp(
int timestamp) → TimeZoneInfo - Sets the timestamp, in milliseconds since Unix epoch, at which to interpret the time zone for display name lookup.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited